<?php
/**
 * finspiration functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 */

if ( ! function_exists( 'finspiration_setup' ) ) :
	/**
	 * finspiration setup.
	 *
	 * Set up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support post thumbnails.
	 *
	 */
	function finspiration_setup() {

		/*
		 * Make theme available for translation.
		 *
		 * Translations can be filed in the /languages/ directory
		 *
		 * If you're building a theme based on finspiration, use a find and replace
		 * to change 'finspiration' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'finspiration', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, and column width.
	 	 */
		add_editor_style( array( 'css/editor-style.css', 
								 get_template_directory_uri() . '/css/font-awesome.css',
								 finspiration_fonts_url()
						  ) );

		/*
		 * Set Custom Background
		 */				 
		add_theme_support( 'custom-background', array ('default-color'  => '#ffffff') );

		// Set the default content width.
		$GLOBALS['content_width'] = 900;

		// This theme uses wp_nav_menu() in header menu
		register_nav_menus( array(
			'primary'   => __( 'Primary Menu', 'finspiration' ),
		) );

		$defaults = array(
	        'flex-height' => false,
	        'flex-width'  => false,
	        'header-text' => array( 'site-title', 'site-description' ),
	    );
	    add_theme_support( 'custom-logo', $defaults );

	    // Define and register starter content to showcase the theme on new sites.
		$starter_content = array(

			'widgets' => array(
				'sidebar-widget-area' => array(
					'search',
					'recent-posts',
					'categories',
					'archives',
				),

				'homepage-widget-area' => array(
					'text_business_info'
				),

				'footer-column-1-widget-area' => array(
					'recent-comments'
				),

				'footer-column-2-widget-area' => array(
					'recent-posts'
				),

				'footer-column-3-widget-area' => array(
					'calendar'
				),
			),

			'posts' => array(
				'home',
				'blog',
				'about',
				'contact'
			),

			// Create the custom image attachments used as slides
			'attachments' => array(
				'image-slide-1' => array(
					'post_title' => _x( 'Slider Image 1', 'Theme starter content', 'finspiration' ),
					'file' => 'images/slider/1.jpg', // URL relative to the template directory.
				),
				'image-slide-2' => array(
					'post_title' => _x( 'Slider Image 2', 'Theme starter content', 'finspiration' ),
					'file' => 'images/slider/2.jpg', // URL relative to the template directory.
				),
				'image-slide-3' => array(
					'post_title' => _x( 'Slider Image 3', 'Theme starter content', 'finspiration' ),
					'file' => 'images/slider/3.jpg', // URL relative to the template directory.
				),
			),

			// Default to a static front page and assign the front and posts pages.
			'options' => array(
				'show_on_front' => 'page',
				'page_on_front' => '{{home}}',
				'page_for_posts' => '{{blog}}',
			),

			// Set the front page section theme mods to the IDs of the core-registered pages.
			'theme_mods' => array(
				'finspiration_slider_display' => 1,
				'finspiration_slide1_image' => '{{image-slider-1}}',
				'finspiration_slide1_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'Theme starter content', 'finspiration' ),
				'finspiration_slide2_image' => '{{image-slider-2}}',
				'finspiration_slide2_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'Theme starter content', 'finspiration' ),
				'finspiration_slide3_image' => '{{image-slider-3}}',
				'finspiration_slide3_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'Theme starter content', 'finspiration' ),
				'finspiration_social_facebook' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_twitter' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_linkedin' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_instagram' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_rss' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_tumblr' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_youtube' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_pinterest' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_vk' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_flickr' => _x( '#', 'Theme starter content', 'finspiration' ),
				'finspiration_social_vine' => _x( '#', 'Theme starter content', 'finspiration' ),
			),

			'nav_menus' => array(

				// Assign a menu to the "primary" location.
				'primary' => array(
					'name' => __( 'Primary Menu', 'finspiration' ),
					'items' => array(
						'link_home',
						'page_blog',
						'page_contact',
						'page_about',
					),
				),
			),
		);

		$starter_content = apply_filters( 'finspiration_starter_content', $starter_content );
		add_theme_support( 'starter-content', $starter_content );
	}
endif; // finspiration_setup
add_action( 'after_setup_theme', 'finspiration_setup' );

if ( ! function_exists( 'finspiration_fonts_url' ) ) :
	/**
	 *	Load google font url used in the finspiration theme
	 */
	function finspiration_fonts_url() {

	    $fonts_url = '';
	 
	    /* Translators: If there are characters in your language that are not
	    * supported by Cormorant Garamond, translate this to 'off'. Do not translate
	    * into your own language.
	    */
	    $questrial = _x( 'on', 'Cormorant Garamond font: on or off', 'finspiration' );

	    if ( 'off' !== $questrial ) {
	        $font_families = array();
	 
	        $font_families[] = 'Cormorant Garamond';
	 
	        $query_args = array(
	            'family' => urlencode( implode( '|', $font_families ) ),
	            'subset' => urlencode( 'latin,latin-ext' ),
	        );
	 
	        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	    }
	 
	    return $fonts_url;
	}
endif; // finspiration_fonts_url

if ( ! function_exists( 'finspiration_load_scripts' ) ) :
	/**
	 * the main function to load scripts in the finspiration theme
	 * if you add a new load of script, style, etc. you can use that function
	 * instead of adding a new wp_enqueue_scripts action for it.
	 */
	function finspiration_load_scripts() {

		// load main stylesheet.
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array( ) );
		wp_enqueue_style( 'finspiration-style', get_stylesheet_uri(), array() );
		
		wp_enqueue_style( 'finspiration-fonts', finspiration_fonts_url(), array(), null );
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Load Slider JS Scripts
		wp_enqueue_script( 'modernizr.custom',
			get_template_directory_uri() . '/js/modernizr.custom.js', array( 'jquery' ) );

		wp_enqueue_script( 'classie',
			get_template_directory_uri() . '/js/classie.js', array( 'modernizr.custom' ) );

		wp_enqueue_script( 'tiltSlider',
			get_template_directory_uri() . '/js/tiltSlider.js', array( 'classie' ) );

		// Load Utilities JS Script
		wp_enqueue_script( 'finspiration-utilities',
			get_template_directory_uri() . '/js/utilities.js', array( 'jquery', 'tiltSlider') );
	}
endif; // finspiration_load_scripts
add_action( 'wp_enqueue_scripts', 'finspiration_load_scripts' );

if ( ! function_exists( 'finspiration_widgets_init' ) ) :
	/**
	 *	widgets-init action handler. Used to register widgets and register widget areas
	 */
	function finspiration_widgets_init() {
		
		// Register Sidebar Widget.
		register_sidebar( array (
							'name'	 		 =>	 __( 'Sidebar Widget Area', 'finspiration'),
							'id'		 	 =>	 'sidebar-widget-area',
							'description'	 =>  __( 'The sidebar widget area', 'finspiration'),
							'before_widget'	 =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
							'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
						) );


		/**
		 * Add Homepage Widget areas
		 */
		register_sidebar( array (
							'name'			 =>  __( 'Homepage Widget Area', 'finspiration' ),
							'id'			 =>  'homepage-widget-area',
							'description' 	 =>  __( 'The homepage widget area', 'finspiration' ),
							'before_widget'	 =>  '<div>',
							'after_widget'	 =>  '</div>',
							'before_title'	 =>  '<h2 class="home-title">',
							'after_title'	 =>  '</h2><div class="home-after-title"></div>',
						) );

		// Register Footer Column #1
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #1', 'finspiration' ),
								'id' 			 =>  'footer-column-1-widget-area',
								'description'	 =>  __( 'The Footer Column #1 widget area', 'finspiration' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
		
		// Register Footer Column #2
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #2', 'finspiration' ),
								'id' 			 =>  'footer-column-2-widget-area',
								'description'	 =>  __( 'The Footer Column #2 widget area', 'finspiration' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
		
		// Register Footer Column #3
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #3', 'finspiration' ),
								'id' 			 =>  'footer-column-3-widget-area',
								'description'	 =>  __( 'The Footer Column #3 widget area', 'finspiration' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
	}
endif; // finspiration_widgets_init
add_action( 'widgets_init', 'finspiration_widgets_init' );

if ( ! function_exists( 'finspiration_display_slider' ) ) :
	/**
	 * Displays the slider
	 */
	function finspiration_display_slider() {
	?>
		<div class="slideshow" id="slideshow">
			<ol class="slides">
		<?php
			// display slides
			for ( $i = 1; $i <= 3; ++$i ) {

					$defaultSlideContent = __( '<h3>This is Default Slide Title</h3><p>You can completely customize Slide Background Image, Title, Text, Link URL and Text.</p><a title="Read more" href="#">Read more</a>', 'finspiration' );
					
					$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';

					$slideContent = get_theme_mod( 'finspiration_slide'.$i.'_content', html_entity_decode( $defaultSlideContent ) );
					$slideImage = get_theme_mod( 'finspiration_slide'.$i.'_image', $defaultSlideImage );

				?>
					<li<?php if ($i == 1) : ?> class="current"<?php endif; ?>>
						<div class="description">
							<?php echo $slideContent; ?>
						</div>
						<div class="tiltview col">
							<a href="#"><img src="<?php echo esc_attr( $slideImage ); ?>" /></a>
						</div>
					</li>
<?php		} ?>
		</ol><!-- .slides -->
	</div><!-- #slideshow -->
<?php 
	}
endif; // finspiration_display_slider

if ( ! function_exists( 'finspiration_show_copyright_text' ) ) :
	/**
	 *	Displays the copyright text.
	 */
	function finspiration_show_copyright_text() {

		$footerText = get_theme_mod('finspiration_footer_copyright', null);

		if ( !empty( $footerText ) ) {

			echo esc_html( $footerText ) . ' | ';		
		}
	}
endif; // finspiration_show_copyright_text


if ( ! function_exists( 'finspiration_custom_header_setup' ) ) :
  /**
   * Set up the WordPress core custom header feature.
   *
   * @uses finspiration_header_style()
   */
  function finspiration_custom_header_setup() {

  	add_theme_support( 'custom-header', array (
                         'default-image'          => '',
                         'flex-height'            => true,
                         'flex-width'             => true,
                         'uploads'                => true,
                         'width'                  => 900,
                         'height'                 => 100,
                         'default-text-color'     => '#434343',
                         'wp-head-callback'       => 'finspiration_header_style',
                      ) );
  }
endif; // finspiration_custom_header_setup
add_action( 'after_setup_theme', 'finspiration_custom_header_setup' );


if ( ! function_exists( 'finspiration_show_social_sites' ) ) :

	function finspiration_show_social_sites() {

		$socialURL = get_theme_mod('finspiration_social_facebook');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Facebook', 'finspiration') . '" class="facebook16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_twitter');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Twitter', 'finspiration') . '" class="twitter16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_linkedin');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on LinkedIn', 'finspiration') . '" class="linkedin16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_instagram');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Instagram', 'finspiration') . '" class="instagram16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_rss');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow our RSS Feeds', 'finspiration') . '" class="rss16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_tumblr');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Tumblr', 'finspiration') . '" class="tumblr16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_youtube');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Youtube', 'finspiration') . '" class="youtube16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_pinterest');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Pinterest', 'finspiration') . '" class="pinterest16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_vk');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on VK', 'finspiration') . '" class="vk16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_flickr');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Flickr', 'finspiration') . '" class="flickr16"></a></li>';
		}

		$socialURL = get_theme_mod('finspiration_social_vine');
		if ( !empty($socialURL) ) {

			echo '<li><a href="' . esc_url( $socialURL ) . '" title="' . __('Follow us on Vine', 'finspiration') . '" class="vine16"></a></li>';
		}
	}

endif; // finspiration_show_social_sites

if ( ! function_exists( 'finspiration_header_style' ) ) :

  /**
   * Styles the header image and text displayed on the blog.
   *
   * @see finspiration_custom_header_setup().
   */
  function finspiration_header_style() {

  	$header_text_color = get_header_textcolor();

      if ( ! has_header_image()
          && ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color
               || 'blank' === $header_text_color ) ) {

          return;
      }

      $headerImage = get_header_image();
  ?>
      <style id="finspiration-custom-header-styles" type="text/css">

          <?php if ( has_header_image() ) : ?>

                  #header-main-fixed {background-image: url("<?php echo esc_url( $headerImage ); ?>");}

          <?php endif; ?>

          <?php if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color
                      && 'blank' !== $header_text_color ) : ?>

                  #header-main-fixed, #header-main-fixed h1.entry-title {color: #<?php echo sanitize_hex_color_no_hash( $header_text_color ); ?>;}

          <?php endif; ?>
      </style>
  <?php
  }
endif; // End of finspiration_header_style.

if ( class_exists('WP_Customize_Section') ) {
	class finspiration_Customize_Section_Pro extends WP_Customize_Section {

		// The type of customize section being rendered.
		public $type = 'finspiration';

		// Custom button text to output.
		public $pro_text = '';

		// Custom pro button URL.
		public $pro_url = '';

		// Add custom parameters to pass to the JS via JSON.
		public function json() {
			$json = parent::json();

			$json['pro_text'] = $this->pro_text;
			$json['pro_url']  = esc_url( $this->pro_url );

			return $json;
		}

		// Outputs the template
		protected function render_template() { ?>

			<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">

				<h3 class="accordion-section-title">
					{{ data.title }}

					<# if ( data.pro_text && data.pro_url ) { #>
						<a href="{{ data.pro_url }}" class="button button-primary alignright" target="_blank">{{ data.pro_text }}</a>
					<# } #>
				</h3>
			</li>
		<?php }
	}
}

/**
 * Singleton class for handling the theme's customizer integration.
 */
final class finspiration_Customize {

	// Returns the instance.
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	// Constructor method.
	private function __construct() {}

	// Sets up initial actions.
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	// Sets up the customizer sections.
	public function sections( $manager ) {

		// Load custom sections.

		// Register custom section types.
		$manager->register_section_type( 'finspiration_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new finspiration_Customize_Section_Pro(
				$manager,
				'finspiration',
				array(
					'title'    => esc_html__( 'tInspiration', 'finspiration' ),
					'pro_text' => esc_html__( 'Upgrade to Pro', 'finspiration' ),
					'pro_url'  => esc_url( 'https://tishonator.com/product/tinspiration' )
				)
			)
		);
	}

	// Loads theme customizer CSS.
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'finspiration-customize-controls', trailingslashit( get_template_directory_uri() ) . 'js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'finspiration-customize-controls', trailingslashit( get_template_directory_uri() ) . 'css/customize-controls.css' );
	}
}

// Doing this customizer thang!
finspiration_Customize::get_instance();

if ( ! function_exists( 'finspiration_sanitize_checkbox' ) ) :
	function finspiration_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
endif;

if ( ! function_exists( 'finspiration_sanitize_html' ) ) :
	function finspiration_sanitize_html( $html ) {
		return wp_filter_post_kses( $html );
	}
endif; // finspiration_sanitize_html

if ( ! function_exists( 'finspiration_sanitize_url' ) ) :
	function finspiration_sanitize_url( $url ) {
		return esc_url_raw( $url );
	}
endif; // finspiration_sanitize_url

if ( ! function_exists( 'finspiration_customize_register' ) ) :
	/**
	 * Add postMessage support for site title and description for the Theme Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	function finspiration_customize_register( $wp_customize ) {

		/**
		 * Add Social Sites Section
		 */
		$wp_customize->add_section(
			'finspiration_social_section',
			array(
				'title'       => __( 'Social Sites', 'finspiration' ),
				'capability'  => 'edit_theme_options',
			)
		);
		
		// Add facebook url
		$wp_customize->add_setting(
			'finspiration_social_facebook',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_facebook',
	        array(
	            'label'          => __( 'Facebook Page URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_facebook',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Twitter url
		$wp_customize->add_setting(
			'finspiration_social_twitter',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_twitter',
	        array(
	            'label'          => __( 'Twitter URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_twitter',
	            'type'           => 'text',
	            )
	        )
		);

		// Add LinkedIn url
		$wp_customize->add_setting(
			'finspiration_social_linkedin',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_linkedin',
	        array(
	            'label'          => __( 'LinkedIn URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_linkedin',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Instagram url
		$wp_customize->add_setting(
			'finspiration_social_instagram',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_instagram',
	        array(
	            'label'          => __( 'LinkedIn URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_instagram',
	            'type'           => 'text',
	            )
	        )
		);

		// Add RSS Feeds url
		$wp_customize->add_setting(
			'finspiration_social_rss',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_rss',
	        array(
	            'label'          => __( 'RSS Feeds URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_rss',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Tumblr url
		$wp_customize->add_setting(
			'finspiration_social_tumblr',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_tumblr',
	        array(
	            'label'          => __( 'Tumblr URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_tumblr',
	            'type'           => 'text',
	            )
	        )
		);

		// Add YouTube channel url
		$wp_customize->add_setting(
			'finspiration_social_youtube',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_youtube',
	        array(
	            'label'          => __( 'YouTube channel URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_youtube',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Pinterest url
		$wp_customize->add_setting(
			'finspiration_social_pinterest',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_pinterest',
	        array(
	            'label'          => __( 'Pinterest URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_pinterest',
	            'type'           => 'text',
	            )
	        )
		);

		// Add VK url
		$wp_customize->add_setting(
			'finspiration_social_vk',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_vk',
	        array(
	            'label'          => __( 'VK URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_vk',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Flickr url
		$wp_customize->add_setting(
			'finspiration_social_flickr',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_flickr',
	        array(
	            'label'          => __( 'Flickr URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_flickr',
	            'type'           => 'text',
	            )
	        )
		);

		// Add Vine url
		$wp_customize->add_setting(
			'finspiration_social_vine',
			array(
			    'sanitize_callback' => 'finspiration_sanitize_url',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_social_vine',
	        array(
	            'label'          => __( 'Vine URL', 'finspiration' ),
	            'section'        => 'finspiration_social_section',
	            'settings'       => 'finspiration_social_vine',
	            'type'           => 'text',
	            )
	        )
		);

		/**
		 * Add Slider Section
		 */
		$wp_customize->add_section(
			'finspiration_slider_section',
			array(
				'title'       => __( 'Slider', 'finspiration' ),
				'capability'  => 'edit_theme_options',
			)
		);

		// Add display slider option
		$wp_customize->add_setting(
				'finspiration_slider_display',
				array(
						'default'           => 0,
						'sanitize_callback' => 'finspiration_sanitize_checkbox',
				)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_slider_display',
								array(
									'label'          => __( 'Display Slider on a Static Front Page', 'finspiration' ),
									'section'        => 'finspiration_slider_section',
									'settings'       => 'finspiration_slider_display',
									'type'           => 'checkbox',
								)
							)
		);
		
		for ($i = 1; $i <= 3; ++$i) {
		
			$slideContentId = 'finspiration_slide'.$i.'_content';
			$slideImageId = 'finspiration_slide'.$i.'_image';
			$defaultSliderImagePath = get_template_directory_uri().'/images/slider/'.$i.'.jpg';
		
			// Add Slide Content
			$wp_customize->add_setting(
				$slideContentId,
				array(
					'sanitize_callback' => 'finspiration_sanitize_html',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, $slideContentId,
										array(
											'label'          => sprintf( esc_html__( 'Slide #%s Content', 'finspiration' ), $i ),
											'section'        => 'finspiration_slider_section',
											'settings'       => $slideContentId,
											'type'           => 'textarea',
											)
										)
			);
			
			// Add Slide Background Image
			$wp_customize->add_setting( $slideImageId,
				array(
					'default' => $defaultSliderImagePath,
					'sanitize_callback' => 'finspiration_sanitize_url'
				)
			);

			$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $slideImageId,
					array(
						'label'   	 => sprintf( esc_html__( 'Slide #%s Image', 'finspiration' ), $i ),
						'section' 	 => 'finspiration_slider_section',
						'settings'   => $slideImageId,
					) 
				)
			);
		}

		/**
		 * Add Footer Section
		 */
		$wp_customize->add_section(
			'finspiration_footer_section',
			array(
				'title'       => __( 'Footer', 'finspiration' ),
				'capability'  => 'edit_theme_options',
			)
		);
		
		// Add Footer Copyright Text
		$wp_customize->add_setting(
			'finspiration_footer_copyright',
			array(
			    'default'           => '',
			    'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'finspiration_footer_copyright',
	        array(
	            'label'          => __( 'Copyright Text', 'finspiration' ),
	            'section'        => 'finspiration_footer_section',
	            'settings'       => 'finspiration_footer_copyright',
	            'type'           => 'text',
	            )
	        )
		);
	}
endif; // finspiration_customize_register
add_action( 'customize_register', 'finspiration_customize_register' );
